//+------------------------------------------------------------------+
//|                                                          RSI.mq5 |
//|                                  Copyright 2024, MetaQuotes Ltd. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2024, MetaQuotes Ltd."
#property link      "https://www.mql5.com"
#property version   "1.00"

#include <Trade\Trade.mqh>
CTrade *Trade;

input group "GENERAL INPUTS"
input int EAMagic = 518;
input int MaxSlippage = 1000;
input int takeprofit = 20;
input int stopLoss = 20;

input group "RSI INPUTS"
input int RSIPeriod = 14;
input ENUM_APPLIED_PRICE InpPrice = PRICE_CLOSE;
input int OSLine = 30;
input int OBLine = 70;

int RSIHandle,MyDigits;
double RsiBuffer[];
double ASK,BID,MyPoint,TP,SL;
int OldNumBars = 0;
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
   TesterHideIndicators(false);
   ChartSetInteger(0,CHART_SHOW_GRID,false);
   ChartSetInteger(0,CHART_MODE,CHART_CANDLES);
   ChartSetInteger(0,CHART_COLOR_BACKGROUND,clrBlack);
   ChartSetInteger(0,CHART_COLOR_FOREGROUND,clrWhite);
   ChartSetInteger(0,CHART_COLOR_CANDLE_BULL,clrLime);
   ChartSetInteger(0,CHART_COLOR_CHART_UP,clrLime);
   ChartSetInteger(0,CHART_COLOR_CANDLE_BEAR,clrRed);
   ChartSetInteger(0,CHART_COLOR_CHART_DOWN,clrRed);
   ChartSetInteger(0,CHART_COLOR_STOP_LEVEL,clrGold);
   ChartSetInteger(0,CHART_SHOW_VOLUMES,false);

   Trade = new CTrade;


   ulong MaxSlippagePoints = MaxSlippage*10;
   Trade.SetDeviationInPoints(MaxSlippagePoints);
   Trade.SetExpertMagicNumber(EAMagic);
   MyDigits = (int)SymbolInfoInteger(_Symbol,SYMBOL_DIGITS);
   MyPoint = SymbolInfoDouble(_Symbol,SYMBOL_POINT);
   TP = takeprofit*MyPoint*10;
   SL = stopLoss*MyPoint*10;

   RSIHandle = iRSI(_Symbol,PERIOD_CURRENT,RSIPeriod,InpPrice);
   ArraySetAsSeries(RsiBuffer,true);

   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {


  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {

   CopyBuffer(RSIHandle,0,0,4,RsiBuffer);
   ASK = SymbolInfoDouble(_Symbol,SYMBOL_ASK);
   BID = SymbolInfoDouble(_Symbol,SYMBOL_BID);

   if(NewBarPresent())
     {
      Buy();
      Sell();
     }


   Comment("RSI Value is : ",RsiBuffer[0]);
  }
//+------------------------------------------------------------------+
bool BuySignal()
  {
   if(RsiBuffer[1]>OSLine&&RsiBuffer[2]<OSLine)
      return true;
   return false;
  }
//+------------------------------------------------------------------+
bool SellSignal()
  {
   if(RsiBuffer[1]<OBLine&&RsiBuffer[2]>OBLine)
      return true;
   return false;
  }

//+------------------------------------------------------------------+
//---
void Buy()
  {
   if(BuySignal())
     {
      if(!Trade.Buy(0.1,_Symbol,ASK,ASK-SL,ASK+TP,"Buy"))
         Print("Failed Buy : ",GetLastError());
     }
  }

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void Sell()
  {
   if(SellSignal())
     {

      if(!Trade.Sell(0.1,_Symbol,BID,BID+SL,BID-TP,"Sell"))
         Print("Failed Sell : ",GetLastError());
     }
  }
//+------------------------------------------------------------------+
bool NewBarPresent()
  {
   int bars = Bars(_Symbol,PERIOD_CURRENT);
   if(OldNumBars!=bars)
     {
      OldNumBars = bars;
      return true;
     }
   return false;
  }
//+------------------------------------------------------------------+
